Pausing and Resuming Animations
-------------------------------
The `.animation.Animation.pause` and `.animation.Animation.resume` methods
allow you to pause and resume animations. These methods can be used as callbacks
for event listeners on UI elements so that your plots can have some playback
control UI.
